@@ -108,6 +108,7 @@ describe 'horizon' do
           :openstack_endpoint_type        => 'internalURL',
           :secondary_endpoint_type        => 'ANY-VALUE',
           :django_debug                   => true,
+          :site_branding                  => 'mysite',
           :api_result_limit               => 4682,
           :compress_offline               => false,
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
@@ -132,7 +133,6 @@ describe 'horizon' do
             { 'name' => 'material', 'label' => 'Material', 'path' => 'themes/material' },
           ],
           :default_theme                  => 'default',
-          :simple_ip_management           => true,
           :password_autocomplete          => 'on',
           :images_panel                   => 'angular',
           :create_image_defaults          => {'image_visibility' => 'private'},
@@ -144,6 +144,7 @@ describe 'horizon' do
       it 'generates local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = True',
+          "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
           'CSRF_COOKIE_SECURE = True',
@@ -151,7 +152,6 @@ describe 'horizon' do
           "  'identity': 2.0,",
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
-          'HORIZON_CONFIG["simple_ip_management"] = True',
           'HORIZON_CONFIG["password_autocomplete"] = "on"',
           'HORIZON_CONFIG["images_panel"] = "angular"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
